package com.notuvy.gui;

import javax.swing.*;
import java.util.HashMap;
import java.util.Map;
import java.awt.event.ActionListener;

/**
 * Logic to construct and define the GUI menu for a frame.
 *
 * User: murali
 * Date: Nov 8, 2010
 * Time: 12:29:32 PM
 */
public class MenuBuilder {

    //------------------------------------------------------------
    //- Class Variables


    //------------------------------------------------------------
    //- Class Functions


    //------------------------------------------------------------
    //- Instance Variables

    private final JMenu fMenu;
    private final Map<String,JMenuItem> fMap = new HashMap<String,JMenuItem>();


    //------------------------------------------------------------
    //- Constructors

    public MenuBuilder(String pMenuName, JMenuBar pMenuBar) {
        fMenu = new JMenu(pMenuName);
        pMenuBar.add(fMenu);
    }

    //------------------------------------------------------------
    //- Getters


    //------------------------------------------------------------
    //- Settors


    //------------------------------------------------------------
    //- Private/Protected Utility Functions


    //------------------------------------------------------------
    //- Public Interface Functions

    public MenuBuilder add(String pItemName) {
        return add(pItemName, null, null);
    }

    public MenuBuilder add(String pItemName, ActionListener pListener) {
        return add(pItemName, pListener, null);
    }

    public MenuBuilder add(String pItemName, ActionListener pListener, KeyStroke pKeyStroke) {
        JMenuItem item = new JMenuItem(pItemName);
        fMap.put(pItemName, item);
        fMenu.add(item);

        if (pListener != null) {
            item.addActionListener(pListener);
        }

        if (pKeyStroke != null) {
            item.setAccelerator(pKeyStroke);
        }

        return this;
    }

    public MenuBuilder addSeparator() {
        fMenu.addSeparator();
        return this;
    }

    public JMenuItem get(String pItemName) {
        return fMap.get(pItemName);
    }

    //------------------------------------------------------------
    //- Class Interface Functions


    //------------------------------------------------------------
    //- Inner Classes


    //------------------------------------------------------------
    //- Main

}